summaryrefslogtreecommitdiffstats
path: root/src/H5Fpublic.h
diff options
context:
space:
mode:
authorVailin Choi <vchoi@jam.ad.hdfgroup.org>2019-04-04 21:29:37 (GMT)
committerVailin Choi <vchoi@jam.ad.hdfgroup.org>2019-04-04 21:29:37 (GMT)
commit0073f198978dea0116bd74816b3119dfeb09144b (patch)
treedb2698fb4cc1d3e332d99834dd2cae170feed2e4 /src/H5Fpublic.h
parentaa696a47715c3dd9c068f71915c6dcf23745441c (diff)
downloadhdf5-0073f198978dea0116bd74816b3119dfeb09144b.zip
hdf5-0073f198978dea0116bd74816b3119dfeb09144b.tar.gz
hdf5-0073f198978dea0116bd74816b3119dfeb09144b.tar.bz2
Set V112 as the latest format and extend the arrays of version bounds.
Diffstat (limited to 'src/H5Fpublic.h')
-rw-r--r--src/H5Fpublic.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/H5Fpublic.h b/src/H5Fpublic.h
index 9f1ed01..8274654 100644
--- a/src/H5Fpublic.h
+++ b/src/H5Fpublic.h
@@ -178,11 +178,12 @@ typedef enum H5F_libver_t {
H5F_LIBVER_ERROR = -1,
H5F_LIBVER_EARLIEST = 0, /* Use the earliest possible format for storing objects */
H5F_LIBVER_V18 = 1, /* Use the latest v18 format for storing objects */
- H5F_LIBVER_V110 = 2, /* Use the latest v10 format for storing objects */
+ H5F_LIBVER_V110 = 2, /* Use the latest v110 format for storing objects */
+ H5F_LIBVER_V112 = 3, /* Use the latest v112 format for storing objects */
H5F_LIBVER_NBOUNDS
} H5F_libver_t;
-#define H5F_LIBVER_LATEST H5F_LIBVER_V110
+#define H5F_LIBVER_LATEST H5F_LIBVER_V112
/* File space handling strategy */
typedef enum H5F_fspace_strategy_t {